@@ -4,12 +4,11 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef GMXIMPORTEXPORTPLUGININTERFACE_H
-#define GMXIMPORTEXPORTPLUGININTERFACE_H
+#pragma once
 
 #include <KAddressBookImportExport/PluginInterface>
 #include <KContacts/Addressee>
-#include <QFile>
+class QFile;
 
 class GMXImportExportPluginInterface : public KAddressBookImportExport::PluginInterface
 {
@@ -30,4 +29,3 @@ private:
     void exportGMX();
 };
 
-#endif // GMXIMPORTEXPORTPLUGININTERFACE_H
