@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CHECKDUPLICATEEMAILSDIALOG_H
-#define CHECKDUPLICATEEMAILSDIALOG_H
+#pragma once
 
 #include <QDialog>
 
@@ -22,7 +21,6 @@ public:
 private:
     void readConfig();
     void writeConfig();
-    QListWidget *mListWidget = nullptr;
+    QListWidget *const mListWidget;
 };
 
-#endif // CHECKDUPLICATEEMAILSDIALOG_H
