@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,7 @@ SelectImapLineEdit::~SelectImapLineEdit()
 
 void SelectImapLineEdit::setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account)
 {
-    //TODO FIXME
+    // TODO FIXME
 #ifdef COMPLETION_LINE_EDIT
     delete mCompleter;
     mCompleter = new QCompleter(this);
@@ -29,6 +29,6 @@ void SelectImapLineEdit::setSieveImapAccountSettings(const KSieveUi::SieveImapAc
     mCompleter->setModel(model->completerModel());
     setCompleter(mCompleter);
 #else
-    Q_UNUSED(account);
+    Q_UNUSED(account)
 #endif
 }
